@@ -18,6 +18,7 @@
 #
 # This translation was updated for Oddmuse 1.354.
 #
+$ModulesDescription .= '<p>$Id: bulgarian-utf8.pl,v 1.1 2005/01/09 01:42:05 as Exp $</p>';
 %Translate = split('\n',<<END_OF_TRANSLATION);
 Reading not allowed: user, ip, or network is blocked.
 Не е разрешено четенето: блокиран потребител, IP адрес или мрежа.
@@ -27,6 +28,8 @@ Invalid UserName %s: not saved.
 Невалидно потребителско име %s: нищо не бе записано.
 UserName must be 50 characters or less: not saved
 Дължината на потребителското име не трябва да надвишава 50 знака: нищо не бе записано.
+This page contains an uploaded file:
+
 XML::RSS is not available on this system.
 Модулът XML::RSS не е инсталиран на тази система.
 diff
@@ -37,10 +40,16 @@ history
 
 RSS parsing failed for %s
 
+No items found in %s.
+
  . . . . 
 
 Click to edit this page
 Кликни тук, за да създадеш тази страница
+image
+
+download
+
 Invalid action parameter %s
 Невалидна команда: %s
 Invalid URL.
@@ -129,6 +138,34 @@ Rollback to %s
 Връщане до %s
 %s rolled back
 Промените върху %s бяха успешно върнати
+Index of all pages
+Индекс на всички страници
+Wiki Version
+Показ на Уики-версия
+Unlock Wiki
+Премахване на защити
+Recent Visitors
+Скорошни посетители
+Password
+Парола
+Run maintenance
+
+Unlock site
+
+Lock site
+
+Unlock %s
+
+Lock %s
+
+Administration
+
+Actions:
+
+Important pages:
+
+To mark a page for deletion, put <strong>%s</strong> on the first line.
+
 [Home]
 [Начална страница]
 redirected from %s
@@ -155,21 +192,9 @@ by %s
 от %s
 (diff)
 (разлики)
-Run maintenance
-
-Unlock site
-
-Lock site
-
-Unlock page
-
-Lock page
-
-Comments on this page
-Коментари към тази страница
 Edit revision %s of this page
 Редакция на версия %s на тази страница
-Edit text of this page
+Edit this page
 Редакция на тази страница
 e
 
@@ -181,10 +206,10 @@ View current revision
 Виж актуалната версия
 View all changes
 Виж всички промени
-Back to %s
-Обратно към %s
 new comment
 Нов коментар
+Homepage URL:
+
 s
 
 Save
@@ -193,6 +218,8 @@ Preview
 Предварителен преглед
 Search:
 Търси:
+f
+
 Replace:
 Замести:
 Validate HTML
@@ -213,6 +240,8 @@ minor
 малка
 No diff available.
 Не са належащи данни за разликите.
+Old revision:
+
 Changed:
 Заместено:
 Removed:
@@ -227,16 +256,16 @@ showing current revision instead
 Вместо това, ето актуалната версия
 Showing revision %s
 Ето версия %s
-Cannot save an nameless page.
+Cannot save a nameless page.
 Не може да се направи запис на безименна страница.
+Cannot save a page without revision.
+
 Cannot open %s
 не може да се отвори: %s
 Cannot write %s
 Не може да се запише: %s
 Could not get %s lock
 Не може да се резервират изключителни права върху %s.
-Unlocking
-Премахване на защити
 This operation may take several seconds...
 Тази операция може да потрае малко...
 Forced unlock of %s lock.
@@ -291,8 +320,6 @@ File to upload:
 Файл за качване: 
 Files of type %s are not allowed.
 Файлове тип %s не са разрешени.
-Password
-Парола
 Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
 Паролата се записва в курабийка (cookie), ако те са разрешени. Курабийките могат да се загубят, ако се свързваш от друг компютър или акаунт, или с друг софтуер.
 You are currently an administrator on this site.
@@ -313,14 +340,18 @@ This operation is restricted to administrators only...
 Тази операция може да се извършва само от администратори.
 Rule "%1" matched "%2" on this page.
 
-Index of all pages
-Индекс на всички страници
-all pages
-всички страници
-permanent anchors
-постоянни точки
-near links
-близки линкове
+Without normal pages
+
+Include normal pages
+
+Without permanent anchors
+
+Include permanent anchors
+
+Without near pages
+
+Include near pages
+
 (for %s)
 (за %s)
 %s pages found.
@@ -347,6 +378,8 @@ Complete Content
 Пълно съдържание
 The main page is %s.
 Главната страница е %s.
+Comments on this page
+Коментари към тази страница
 Editing not allowed for %s.
 Редакция на %s не е разрешена.
 SampleUndefinedPage
@@ -377,6 +410,12 @@ Please check whether you overwrote those changes.
 Моля провери, дали няма конфликт между промените.
 Anonymous
 Анонимен
+Cannot delete the index file %s.
+
+Please check the directory permissions.
+
+Your changes were not saved.
+
 Could not get a lock to merge!
 Не може да се придобият изключителни права за сливане!
 you
@@ -385,8 +424,8 @@ ancestor
 предшественик
 other
 друг
-Maintenance on all pages
-Поддръжка на всички страници
+Run Maintenance
+
 Maintenance not done.
 Поддъжката не бе осъществена.
 (Maintenance can only be done once every 12 hours.)
@@ -424,23 +463,21 @@ Lock for %s created.
 Lock for %s removed.
 Защитата за %s бе отменена.
 Displaying Wiki Version
-Показ на Уики-версия
+
+Show dependencies
+
 Inter links:
 Интер-линкове:
 Near links:
 Близки линкове:
+Show parsed link data
+
 Too many connections by %s
 Прекалено много връзки с %s
 Please do not fetch more than %1 pages in %2 seconds.
 
 Check whether the web server can create the directory %s and whether it can create files in it.
 
-Recent Visitors
-Скорошни посетители
-Referrers
-Линкове
-All Referrers
-Всички линкове
 anchor first defined here: %s
 Точката бе първо дефинирана тук: %s
 Click to search for references to this permanent anchor
@@ -463,9 +500,9 @@ Renamed from %s
 
 Renamed %1 to %2.
 
-Delete page
+Immediately delete %s
 
-Rename this page to:
+Rename %s to:
 
 Cannot highlight the language %s.
 
@@ -481,8 +518,28 @@ Next
 
 Calendar %s
 
+Comments on 
+
+Comment on 
+
+Compilation for %s
+
+Compilation tag is missing a regular expression.
+
+Despamming pages
+
+Cannot find revision %s.
+
+Revert to revision %1: %2
+
+Marked as %s.
+
+Cannot find unspammed revision.
+
 Footnotes:
 
+Could not find %1.html template in %2
+
 image: %s
 
 Index
@@ -495,6 +552,12 @@ Define
 
 Full Link List
 Пълен списък на линковете
+Template without parameters
+
+The template %s is either empty or does not exist.
+
+%s returned no data.
+
 Clearing Cache
 
 Done.
@@ -515,8 +578,20 @@ Permalink to "%s"
 
 Portrait
 
+You did not answer correctly.
+
+All Referrers
+Всички линкове
+Referrers
+Линкове
+Updating %s
+
+Search term missing.
+
 Static Copy
 
+Back to %s
+Обратно към %s
 Alternatively, use one of the following templates:
 
 Thread: %s
@@ -541,6 +616,10 @@ Name:
 
 Failed to remove %s
 
+Contents
+
+This page is a translation of %s. 
+
 The translation is up to date.
 
 The translation is outdated.
