@@ -24,6 +24,7 @@
 #
 # This translation was last checked for Oddmuse version 1.215.
 #
+$ModulesDescription .= '<p>$Id: dutch-utf8.pl,v 1.1 2005/01/09 01:42:05 as Exp $</p>';
 %Translate = split('\n',<<END_OF_TRANSLATION);
 Reading not allowed: user, ip, or network is blocked.
 U mag deze pagina niet lezen: uw account op deze Wiki, uw IP of uw netwerk is buitengesloten.
@@ -33,6 +34,8 @@ Invalid UserName %s: not saved.
 Niet opgeslagen: de GebruikersNaam %s is ongeldig.
 UserName must be 50 characters or less: not saved
 Niet opgeslagen: de GebruikersNaam mag hoogstens 50 tekens lang zijn.
+This page contains an uploaded file:
+
 XML::RSS is not available on this system.
 XML::RSS is niet beschikbaar op dit systeem.
 diff
@@ -43,10 +46,16 @@ geschiedenis
 %s retourneerde geen data, of LWP::UserAgent is niet beschikbaar.
 RSS parsing failed for %s
 Lezen van RSS is niet gelukt voor %s
+No items found in %s.
+
  . . . . 
 
 Click to edit this page
 Klik hier om deze pagina aan te maken
+image
+
+download
+
 Invalid action parameter %s
 Ongeldige actieparameter %s
 Invalid URL.
@@ -135,6 +144,34 @@ Rollback to %s
 Wijzigingen ongedaan maken tot %s
 %s rolled back
 %s is in de oorspronkelijke staat teruggebracht
+Index of all pages
+Index van alle pagina's
+Wiki Version
+Tonen van Wiki-versie
+Unlock Wiki
+Bezig met ontgrendelen
+Recent Visitors
+Recente bezoekers
+Password
+Wachtwoord
+Run maintenance
+Voor onderhoud uit
+Unlock site
+Ontgrendel site
+Lock site
+Vergrendel site
+Unlock %s
+
+Lock %s
+
+Administration
+
+Actions:
+
+Important pages:
+
+To mark a page for deletion, put <strong>%s</strong> on the first line.
+
 [Home]
 [Start]
 redirected from %s
@@ -161,21 +198,9 @@ by %s
 door %s
 (diff)
 (verschillen)
-Run maintenance
-Voor onderhoud uit
-Unlock site
-Ontgrendel site
-Lock site
-Vergrendel site
-Unlock page
-Ontgrendel pagina
-Lock page
-Vergrendel pagina
-Comments on this page
-Commentaar op deze pagina
 Edit revision %s of this page
 Wijzig revisie %s van deze pagina
-Edit text of this page
+Edit this page
 Wijzig de tekst op deze pagina
 e
 e
@@ -187,10 +212,10 @@ View current revision
 Bekijk huidige revisie
 View all changes
 Toon alle wijzigingen
-Back to %s
-Terug naar %s
 new comment
 nieuw commentaar
+Homepage URL:
+
 s
 s
 Save
@@ -199,6 +224,8 @@ Preview
 Voorvertoning
 Search:
 Zoeken naar:
+f
+
 Replace:
 Vervangen door:
 Validate HTML
@@ -219,6 +246,8 @@ minor
 klein
 No diff available.
 Er is geen verschillenanalyse beschikbaar.
+Old revision:
+
 Changed:
 Veranderd:
 Removed:
@@ -233,16 +262,16 @@ showing current revision instead
 in plaats daarvan ziet u nu de huidige revisie
 Showing revision %s
 Dit is revisie %s
-Cannot save an nameless page.
+Cannot save a nameless page.
 Kan een pagina zonder naam niet opslaan.
+Cannot save a page without revision.
+
 Cannot open %s
 Kan %s niet openen
 Cannot write %s
 Kan %s niet wijzigen
 Could not get %s lock
 Kan %s niet vergrendelen
-Unlocking
-Bezig met ontgrendelen
 This operation may take several seconds...
 Dit kan een aantal seconden duren...
 Forced unlock of %s lock.
@@ -297,8 +326,6 @@ File to upload:
 Te publiceren bestand: 
 Files of type %s are not allowed.
 Bestanden van het type %s zijn niet toegestaan.
-Password
-Wachtwoord
 Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
 Als uw browser gebruik maakt van cookies, is uw wachtwoord in een cookie opgeslagen. Cookies kunnen verloren gaan als u verbinding maakt vanaf een andere machine, vanaf een ander account of met behulp van andere software.
 You are currently an administrator on this site.
@@ -319,14 +346,18 @@ This operation is restricted to administrators only...
 Deze taak mag alleen uitgevoerd worden door beheerders...
 Rule "%1" matched "%2" on this page.
 
-Index of all pages
-Index van alle pagina's
-all pages
-alle pagina's
-permanent anchors
-permanente bladwijzers
-near links
-nabije koppelingen
+Without normal pages
+
+Include normal pages
+
+Without permanent anchors
+
+Include permanent anchors
+
+Without near pages
+
+Include near pages
+
 (for %s)
 (voor %s)
 %s pages found.
@@ -353,6 +384,8 @@ Complete Content
 Volledige inhoud
 The main page is %s.
 De hoofdpagina is %s.
+Comments on this page
+Commentaar op deze pagina
 Editing not allowed for %s.
 Het wijzigen van %s is niet toegestaan.
 SampleUndefinedPage
@@ -383,6 +416,12 @@ Please check whether you overwrote those changes.
 Controleer a.u.b. of u die wijzigingen overschreven heeft.
 Anonymous
 Anoniem
+Cannot delete the index file %s.
+
+Please check the directory permissions.
+
+Your changes were not saved.
+
 Could not get a lock to merge!
 Kan de pagina niet vergrendelen voor het samenvoegen
 you
@@ -391,8 +430,8 @@ ancestor
 vorige revisie
 other
 ander
-Maintenance on all pages
-Onderhoud van alle pagina's
+Run Maintenance
+
 Maintenance not done.
 Er is geen onderhoud gepleegd.
 (Maintenance can only be done once every 12 hours.)
@@ -430,23 +469,21 @@ Lock for %s created.
 Lock for %s removed.
 %s is ontgrendeld, en kan nu weer gewijzigd worden.
 Displaying Wiki Version
-Tonen van Wiki-versie
+
+Show dependencies
+
 Inter links:
 Interkoppelingen:
 Near links:
 Nabije koppelingen:
+Show parsed link data
+
 Too many connections by %s
 Te veel verbindingen met %s
 Please do not fetch more than %1 pages in %2 seconds.
 Haal a.u.b. niet meer dan %s pagina's op in %2 seconden.
 Check whether the web server can create the directory %s and whether it can create files in it.
 
-Recent Visitors
-Recente bezoekers
-Referrers
-Verwijzingen
-All Referrers
-Alle verwijzingen
 anchor first defined here: %s
 bladwijzer als eerste hier gedefinieerd: %s
 Click to search for references to this permanent anchor
@@ -469,10 +506,10 @@ Renamed from %s
 Hernoemd van %s
 Renamed %1 to %2.
 %1 hernoemd in %2.
-Delete page
-Verwijder pagina
-Rename this page to:
-Hernoem deze pagina in:
+Immediately delete %s
+
+Rename %s to:
+
 Cannot highlight the language %s.
 
 Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.
@@ -487,8 +524,28 @@ Next
 
 Calendar %s
 Kalender %s
+Comments on 
+
+Comment on 
+
+Compilation for %s
+
+Compilation tag is missing a regular expression.
+
+Despamming pages
+
+Cannot find revision %s.
+
+Revert to revision %1: %2
+
+Marked as %s.
+
+Cannot find unspammed revision.
+
 Footnotes:
 Voetnoten:
+Could not find %1.html template in %2
+
 image: %s
 afbeelding: %s
 Index
@@ -498,13 +555,19 @@ Talen:
 Show!
 Tonen!
 Define
-Definiren
+Definiëren
 Full Link List
 Volledige lijst van koppelingen
+Template without parameters
+
+The template %s is either empty or does not exist.
+
+%s returned no data.
+
 Clearing Cache
 Bezig met leegmaken van de cache
 Done.
-Klaar.
+
 Generating Link Database
 Bezig met genereren van Koppelingendatabase
 The 404 handler extension requires the link data extension (links.pl).
@@ -521,8 +584,20 @@ Permalink to "%s"
 
 Portrait
 Portret
+You did not answer correctly.
+
+All Referrers
+Alle verwijzingen
+Referrers
+Verwijzingen
+Updating %s
+
+Search term missing.
+
 Static Copy
 
+Back to %s
+Terug naar %s
 Alternatively, use one of the following templates:
 
 Thread: %s
@@ -547,6 +622,10 @@ Name:
 Naam:
 Failed to remove %s
 
+Contents
+
+This page is a translation of %s. 
+
 The translation is up to date.
 
 The translation is outdated.
