@@ -16,6 +16,7 @@
 # Create a modules subdirectory in your data directory, and put the
 # file in there. It will be loaded automatically.
 #
+$ModulesDescription .= '<p>$Id: german-utf8.pl,v 1.1 2005/01/09 01:42:05 as Exp $</p>';
 %Translate = split('\n',<<END_OF_TRANSLATION);
 Reading not allowed: user, ip, or network is blocked.
 Lesen nicht erlaubt: Benutzer, IP oder Netzwerk ist gesperrt.
@@ -25,6 +26,8 @@ Invalid UserName %s: not saved.
 Ungültiger Benutzername %s: nicht gespeichert.
 UserName must be 50 characters or less: not saved
 Länge des Benutzernamens maximal 50 Zeichen: nicht gespeichert.
+This page contains an uploaded file:
+
 XML::RSS is not available on this system.
 Das XML::RSS Modul ist auf diesem System nicht installiert.
 diff
@@ -35,10 +38,16 @@ alte Versionen
 Entweder liefert %s liefert keine Daten, oder das LWP::UserAgent Modul ist auf diesem System nicht installiert.
 RSS parsing failed for %s
 Die RSS Daten von %s sind ungültig; sie können nicht verarbeitet werden
+No items found in %s.
+%s liefert keine Artikel
  . . . . 
  . . . . 
 Click to edit this page
 Hier klicken um die Seite zu bearbeiten
+image
+
+download
+
 Invalid action parameter %s
 Ungültiger action Parameter: %s
 Invalid URL.
@@ -127,6 +136,34 @@ Rollback to %s
 Rückgängig gemacht auf den Stand vom %s
 %s rolled back
 Änderungen für %s rückgängig gemacht
+Index of all pages
+Index aller Seiten
+Wiki Version
+Wiki Version
+Unlock Wiki
+Aufheben der Sperren
+Recent Visitors
+Kürzliche Besucher
+Password
+Passwort
+Run maintenance
+Wartungsarbeiten durchführen
+Unlock site
+Wiki entsperren
+Lock site
+Wiki sperren
+Unlock %s
+
+Lock %s
+
+Administration
+
+Actions:
+
+Important pages:
+
+To mark a page for deletion, put <strong>%s</strong> on the first line.
+
 [Home]
 [Erste Seite]
 redirected from %s
@@ -153,21 +190,9 @@ by %s
 von %s
 (diff)
 (Unterschiede)
-Run maintenance
-Wartungsarbeiten durchführen
-Unlock site
-Wiki entsperren
-Lock site
-Wiki sperren
-Unlock page
-Seite entsperren
-Lock page
-Seite sperren
-Comments on this page
-Kommentare zu dieser Seite
 Edit revision %s of this page
 Version %s dieser Seite bearbeiten
-Edit text of this page
+Edit this page
 Diese Seite bearbeiten
 e
 b
@@ -179,10 +204,10 @@ View current revision
 Zurück zur aktuellen Version
 View all changes
 Liste aller Änderungen, auch ohne vorhandener Version
-Back to %s
-Zurück zu %s
 new comment
 Neuer Kommentar
+Homepage URL:
+
 s
 s
 Save
@@ -191,6 +216,8 @@ Preview
 Vorschau
 Search:
 Suchen:
+f
+
 Replace:
 Ersetzen mit:
 Validate HTML
@@ -211,6 +238,8 @@ minor
 kleinere
 No diff available.
 Keine Unterschiede vorhanden.
+Old revision:
+Alte Version:
 Changed:
 Geändert:
 Removed:
@@ -225,16 +254,16 @@ showing current revision instead
 Stattdessen Anzeige der aktuellen Version
 Showing revision %s
 Anzeige der alten Version %s
-Cannot save an nameless page.
+Cannot save a nameless page.
 Eine Seite ohne Namen kann nicht gespeichert werden.
+Cannot save a page without revision.
+Ohne Version kann die Seite nicht gespeichert werden.
 Cannot open %s
 %s kann nicht geöffnet werden
 Cannot write %s
 %s kann nicht geschrieben werden
 Could not get %s lock
 Die %s Sperre konnte nicht gesetzt werden.
-Unlocking
-Aufheben der Sperren
 This operation may take several seconds...
 Das könnte einige Sekunden dauern...
 Forced unlock of %s lock.
@@ -289,8 +318,6 @@ File to upload:
 Hochzuladende Datei: 
 Files of type %s are not allowed.
 Der Dateityp %s ist nicht erlaubt.
-Password
-Passwort
 Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
 Ihr Passwort wird in einem Cookie gespeichert, falls Sie Cookies eingeschaltet haben. Cookies können verloren gehen, wenn Sie die Verbindung von einer anderen Maschine, von einem anderen Account oder mit anderer Software herstellen.
 You are currently an administrator on this site.
@@ -310,15 +337,19 @@ Diese Aktion darf nur von Bearbeitern durchgeführt werden...
 This operation is restricted to administrators only...
 Diese Aktion darf nur von Administratoren durchgeführt werden...
 Rule "%1" matched "%2" on this page.
+Auf dieser Seite verstösst "%2" gegen die Regel "%1".
+Without normal pages
+
+Include normal pages
+
+Without permanent anchors
+
+Include permanent anchors
+
+Without near pages
+
+Include near pages
 
-Index of all pages
-Index aller Seiten
-all pages
-alle Seiten
-permanent anchors
-permanente Anker
-near links
-"nahe" Seiten
 (for %s)
 (für %s)
 %s pages found.
@@ -345,6 +376,8 @@ Complete Content
 Vollständiger Inhalt
 The main page is %s.
 Die Hauptseite ist %s.
+Comments on this page
+Kommentare zu dieser Seite
 Editing not allowed for %s.
 Das bearbeiten von %s ist nicht erlaubt.
 SampleUndefinedPage
@@ -375,6 +408,12 @@ Please check whether you overwrote those changes.
 Bitte überprüfen Sie, ob diese Änderungen überschrieben worden sind.
 Anonymous
 Unbekannt
+Cannot delete the index file %s.
+
+Please check the directory permissions.
+
+Your changes were not saved.
+
 Could not get a lock to merge!
 Sperre zum automatischen Abgleichen zweier Versionen konnte nicht reserviert werden!
 you
@@ -383,8 +422,8 @@ ancestor
 Vorgänger
 other
 Andere Person
-Maintenance on all pages
-Wartungsarbeiten auf allen Seiten
+Run Maintenance
+
 Maintenance not done.
 Wartungsarbeiten nicht erfolgt.
 (Maintenance can only be done once every 12 hours.)
@@ -422,23 +461,21 @@ Sperre von %s erzeugt.
 Lock for %s removed.
 Sperre von %s aufheben.
 Displaying Wiki Version
-Anzeige der Wiki Version
+
+Show dependencies
+Abhängigkeiten zeigen
 Inter links:
 Inter Links:
 Near links:
 Nahe Links:
+Show parsed link data
+Eingelesene Link Daten anzeigen
 Too many connections by %s
 Zu viele Verbindungen durch %s
 Please do not fetch more than %1 pages in %2 seconds.
 Bitte rufen sie nicht mehr als %1 Seiten in %2 Sekunden auf.
 Check whether the web server can create the directory %s and whether it can create files in it.
-
-Recent Visitors
-Kürzliche Besucher
-Referrers
-Links auf diese Seite
-All Referrers
-Alle Links auf diesen Wiki
+Vielleicht kann der web server das Verzeichnis %s nicht anlegen, oder es wurde schon angelegt, aber der web server kann darin keine neuen Dateien anlegen.
 anchor first defined here: %s
 Der Anker wurde hier zuerst definiert: %s
 Click to search for references to this permanent anchor
@@ -461,12 +498,12 @@ Renamed from %s
 Ehemals %s
 Renamed %1 to %2.
 Die %1 Seite wurde zu %2 umbenannt
-Delete page
-Seite löschen
-Rename this page to:
-Bennen diese Seite um:
-Cannot highlight the language %s.
+Immediately delete %s
 
+Rename %s to:
+
+Cannot highlight the language %s.
+Die Sprache %s kann von diesem Modul nicht eingefärbt werden.
 Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.
 Um einen Kalender zu produzieren fehlt entweder cal(1), Date::Calc(3) oder Date::Pcalc(3).
 The match parameter is missing.
@@ -474,17 +511,37 @@ Der 'match' Parameter fehlt noch.
 Page Collection for %s
 Seitensammlung für %s
 Previous
-
+Vorheriger
 Next
-
+Nächster
 Calendar %s
 Kalender %s
+Comments on 
+
+Comment on 
+
+Compilation for %s
+Zusammenstellung für %s
+Compilation tag is missing a regular expression.
+Der tag für die Zusammenstellung benötigt noch ein Suchmuster.
+Despamming pages
+Spam entfernen
+Cannot find revision %s.
+Die Version %s ist verschwunden.
+Revert to revision %1: %2
+Auf Version %1 zurückgesetzt: %2
+Marked as %s.
+Mit %s markiert. 
+Cannot find unspammed revision.
+Es gibt keine Version ohne Spam.
 Footnotes:
 Fussnoten:
+Could not find %1.html template in %2
+Im Verzeichnis %2 gibt es kein %1.html Template
 image: %s
 Bild: %s
 Index
-
+Index
 Languages:
 Sprachen:
 Show!
@@ -493,10 +550,16 @@ Define
 Definieren
 Full Link List
 Liste aller Verweise
+Template without parameters
+Vorlage ohne Parameter
+The template %s is either empty or does not exist.
+Die %s Vorlage ist entweder leer oder existiert gar nicht.
+%s returned no data.
+
 Clearing Cache
 Cache wird geleert
 Done.
-Fertig.
+
 Generating Link Database
 Verweis Datenbank wird angelegt
 The 404 handler extension requires the link data extension (links.pl).
@@ -510,13 +573,25 @@ Keiner
 Type
 Typ
 Permalink to "%s"
+Permalink für "%s"
+Portrait
+Portrait
+You did not answer correctly.
+
+All Referrers
+Alle Links auf diesen Wiki
+Referrers
+Links auf diese Seite
+Updating %s
+
+Search term missing.
 
-Portrait
-Portrait
 Static Copy
-
+Statische Kopie
+Back to %s
+Zurück zu %s
 Alternatively, use one of the following templates:
-
+Anderenfalls stehen auch folgende Vorlagen zur Verfügung:
 Thread: %s
 Thread: %s
 ID parameter is missing.
@@ -538,13 +613,17 @@ URL:
 Name:
 Name:
 Failed to remove %s
+%s konnte nicht entfernt werden.
+Contents
+Inhaltsverzeichnis
+This page is a translation of %s. 
 
 The translation is up to date.
-
+Die Übersetztung ist aktuell.
 The translation is outdated.
-
+Die Übersetzung ist veraltet.
 The page does not exist.
-
+Die Seite existiert nicht.
 http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s
 http://www.kelkoo.de/shopbot/search.jsp?from=shopbot&catPath=de%2Fbook&catId=100801&title=&author=&isbn=%s&maxprice=&x=36&y=9
 http://www.amazon.com/exec/obidos/ISBN=%s
@@ -557,6 +636,4 @@ search
 Suchen
 Blog
 Blog
-Contents
-Inhaltsverzeichnis
 END_OF_TRANSLATION
