@@ -15,6 +15,7 @@
 # Create a modules subdirectory in your data directory, and put the
 # file in there. It will be loaded automatically.
 #
+$ModulesDescription .= '<p>$Id: new-utf8.pl,v 1.1 2005/01/09 01:42:05 as Exp $</p>';
 %Translate = split('\n',<<END_OF_TRANSLATION);
 Reading not allowed: user, ip, or network is blocked.
 
@@ -24,6 +25,8 @@ Invalid UserName %s: not saved.
 
 UserName must be 50 characters or less: not saved
 
+This page contains an uploaded file:
+
 XML::RSS is not available on this system.
 
 diff
@@ -34,10 +37,16 @@ history
 
 RSS parsing failed for %s
 
+No items found in %s.
+
  . . . . 
 
 Click to edit this page
 
+image
+
+download
+
 Invalid action parameter %s
 
 Invalid URL.
@@ -126,6 +135,34 @@ Rollback to %s
 
 %s rolled back
 
+Index of all pages
+
+Wiki Version
+
+Unlock Wiki
+
+Recent Visitors
+
+Password
+
+Run maintenance
+
+Unlock site
+
+Lock site
+
+Unlock %s
+
+Lock %s
+
+Administration
+
+Actions:
+
+Important pages:
+
+To mark a page for deletion, put <strong>%s</strong> on the first line.
+
 [Home]
 
 redirected from %s
@@ -152,21 +189,9 @@ by %s
 
 (diff)
 
-Run maintenance
-
-Unlock site
-
-Lock site
-
-Unlock page
-
-Lock page
-
-Comments on this page
-
 Edit revision %s of this page
 
-Edit text of this page
+Edit this page
 
 e
 
@@ -178,10 +203,10 @@ View current revision
 
 View all changes
 
-Back to %s
-
 new comment
 
+Homepage URL:
+
 s
 
 Save
@@ -190,6 +215,8 @@ Preview
 
 Search:
 
+f
+
 Replace:
 
 Validate HTML
@@ -210,6 +237,8 @@ minor
 
 No diff available.
 
+Old revision:
+
 Changed:
 
 Removed:
@@ -224,7 +253,9 @@ showing current revision instead
 
 Showing revision %s
 
-Cannot save an nameless page.
+Cannot save a nameless page.
+
+Cannot save a page without revision.
 
 Cannot open %s
 
@@ -232,8 +263,6 @@ Cannot write %s
 
 Could not get %s lock
 
-Unlocking
-
 This operation may take several seconds...
 
 Forced unlock of %s lock.
@@ -288,8 +317,6 @@ File to upload:
 
 Files of type %s are not allowed.
 
-Password
-
 Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
 
 You are currently an administrator on this site.
@@ -310,13 +337,17 @@ This operation is restricted to administrators only...
 
 Rule "%1" matched "%2" on this page.
 
-Index of all pages
+Without normal pages
 
-all pages
+Include normal pages
 
-permanent anchors
+Without permanent anchors
 
-near links
+Include permanent anchors
+
+Without near pages
+
+Include near pages
 
 (for %s)
 
@@ -344,6 +375,8 @@ Complete Content
 
 The main page is %s.
 
+Comments on this page
+
 Editing not allowed for %s.
 
 SampleUndefinedPage
@@ -374,6 +407,12 @@ Please check whether you overwrote those changes.
 
 Anonymous
 
+Cannot delete the index file %s.
+
+Please check the directory permissions.
+
+Your changes were not saved.
+
 Could not get a lock to merge!
 
 you
@@ -382,7 +421,7 @@ ancestor
 
 other
 
-Maintenance on all pages
+Run Maintenance
 
 Maintenance not done.
 
@@ -422,22 +461,20 @@ Lock for %s removed.
 
 Displaying Wiki Version
 
+Show dependencies
+
 Inter links:
 
 Near links:
 
+Show parsed link data
+
 Too many connections by %s
 
 Please do not fetch more than %1 pages in %2 seconds.
 
 Check whether the web server can create the directory %s and whether it can create files in it.
 
-Recent Visitors
-
-Referrers
-
-All Referrers
-
 anchor first defined here: %s
 
 Click to search for references to this permanent anchor
@@ -460,9 +497,9 @@ Renamed from %s
 
 Renamed %1 to %2.
 
-Delete page
+Immediately delete %s
 
-Rename this page to:
+Rename %s to:
 
 Cannot highlight the language %s.
 
@@ -478,8 +515,28 @@ Next
 
 Calendar %s
 
+Comments on 
+
+Comment on 
+
+Compilation for %s
+
+Compilation tag is missing a regular expression.
+
+Despamming pages
+
+Cannot find revision %s.
+
+Revert to revision %1: %2
+
+Marked as %s.
+
+Cannot find unspammed revision.
+
 Footnotes:
 
+Could not find %1.html template in %2
+
 image: %s
 
 Index
@@ -492,6 +549,12 @@ Define
 
 Full Link List
 
+Template without parameters
+
+The template %s is either empty or does not exist.
+
+%s returned no data.
+
 Clearing Cache
 
 Done.
@@ -512,8 +575,20 @@ Permalink to "%s"
 
 Portrait
 
+You did not answer correctly.
+
+All Referrers
+
+Referrers
+
+Updating %s
+
+Search term missing.
+
 Static Copy
 
+Back to %s
+
 Alternatively, use one of the following templates:
 
 Thread: %s
@@ -538,6 +613,10 @@ Name:
 
 Failed to remove %s
 
+Contents
+
+This page is a translation of %s. 
+
 The translation is up to date.
 
 The translation is outdated.
