@@ -17,6 +17,7 @@
 #
 # This translation was last checked for Oddmuse version 1.195.
 #
+$ModulesDescription .= '<p>$Id: portuguese-utf8.pl,v 1.1 2005/01/09 01:42:05 as Exp $</p>';
 %Translate = split('\n',<<END_OF_TRANSLATION);
 Reading not allowed: user, ip, or network is blocked.
 Leitura não permitida: usuário, ip, ou rede está bloqueada.
@@ -26,6 +27,8 @@ Invalid UserName %s: not saved.
 Usuário inválido %s: nada salvo.
 UserName must be 50 characters or less: not saved
 NomeUsuario deve ter 50 caracteres ou menos: nada salvo
+This page contains an uploaded file:
+
 XML::RSS is not available on this system.
 XML::RSS não existe neste sistema
 diff
@@ -36,10 +39,16 @@ história
 
 RSS parsing failed for %s
 
+No items found in %s.
+
  . . . . 
 
 Click to edit this page
 
+image
+
+download
+
 Invalid action parameter %s
 Parametro de ação inválido %s
 Invalid URL.
@@ -128,6 +137,34 @@ Rollback to %s
 
 %s rolled back
 
+Index of all pages
+Índice de todas as páginas
+Wiki Version
+Mostrando versão do Wiki
+Unlock Wiki
+Destravando
+Recent Visitors
+Visitantes recentes
+Password
+Senha
+Run maintenance
+Manutenção
+Unlock site
+
+Lock site
+
+Unlock %s
+
+Lock %s
+
+Administration
+
+Actions:
+
+Important pages:
+
+To mark a page for deletion, put <strong>%s</strong> on the first line.
+
 [Home]
 [Ínicio]
 redirected from %s
@@ -154,22 +191,10 @@ by %s
 de %s
 (diff)
 (diff)
-Run maintenance
-Manutenção
-Unlock site
-
-Lock site
-
-Unlock page
-
-Lock page
-
-Comments on this page
-Commentários sobre esta página
 Edit revision %s of this page
 Edite a revisão %s desta página
-Edit text of this page
-Edite o texto desta página
+Edit this page
+Edite esta página
 e
 
 This page is read-only
@@ -180,10 +205,10 @@ View current revision
 Veja a versão corrente
 View all changes
 Veja todas os câmbios
-Back to %s
-Voltar para %s
 new comment
 Comentário novo
+Homepage URL:
+
 s
 s
 Save
@@ -192,6 +217,8 @@ Preview
 Prever
 Search:
 Busca:
+f
+
 Replace:
 
 Validate HTML
@@ -212,6 +239,8 @@ minor
 simples
 No diff available.
 Nenhum diff disponivel.
+Old revision:
+Revisão antiga:
 Changed:
 Alterado:
 Removed:
@@ -226,16 +255,16 @@ showing current revision instead
 ao invéz mostrando versão corrente
 Showing revision %s
 Mostrando versão %s
-Cannot save an nameless page.
+Cannot save a nameless page.
 Não se pode salvar uma página sem nome.
+Cannot save a page without revision.
+Não se pode salvar uma página sem revisão.
 Cannot open %s
 Não foi possível abrir %s
 Cannot write %s
 Não foi possível escrever %s
 Could not get %s lock
 Não foi possível conseguir a trava %s
-Unlocking
-Destravando
 This operation may take several seconds...
 Essa operação pode demorar alguns segundos...
 Forced unlock of %s lock.
@@ -290,8 +319,6 @@ File to upload:
 Archivo à usar: 
 Files of type %s are not allowed.
 
-Password
-Senha
 Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
 Sua senha é salva em um cookie, caso esteja ativado no seu navegador. Cookies podem se perder se você conectar de outra maquina, outra conta, ou outro software.
 You are currently an administrator on this site.
@@ -312,13 +339,17 @@ This operation is restricted to administrators only...
 Essa operação é restrita aos administradores...
 Rule "%1" matched "%2" on this page.
 
-Index of all pages
-Índice de todas as páginas
-all pages
-todas as páginas
-permanent anchors
+Without normal pages
 
-near links
+Include normal pages
+
+Without permanent anchors
+
+Include permanent anchors
+
+Without near pages
+
+Include near pages
 
 (for %s)
 (para %s)
@@ -346,6 +377,8 @@ Complete Content
 Conteúdo completo
 The main page is %s.
 A página principal é %s.
+Comments on this page
+Commentários sobre esta página
 Editing not allowed for %s.
 Edição não permitida para %s.
 SampleUndefinedPage
@@ -376,6 +409,12 @@ Please check whether you overwrote those changes.
 Se faz favor controle se você  esses câmbios.
 Anonymous
 Anônimo
+Cannot delete the index file %s.
+
+Please check the directory permissions.
+
+Your changes were not saved.
+
 Could not get a lock to merge!
 Não foi possivel pegar a trava para combinar!
 you
@@ -384,8 +423,8 @@ ancestor
 o que já estava
 other
 o que a outra pessoa escreveu
-Maintenance on all pages
-Manutenção em todas as páginas
+Run Maintenance
+
 Maintenance not done.
 Manutenção não concluída.
 (Maintenance can only be done once every 12 hours.)
@@ -423,23 +462,21 @@ Trava para %s criado.
 Lock for %s removed.
 Trava para %s removido:
 Displaying Wiki Version
-Mostrando versão do Wiki
+
+Show dependencies
+
 Inter links:
 
 Near links:
 
+Show parsed link data
+
 Too many connections by %s
 Muitas conexões de %s
 Please do not fetch more than %1 pages in %2 seconds.
 Se faz favor não busque mais do que %1 páginas em %2 segundos.
 Check whether the web server can create the directory %s and whether it can create files in it.
 
-Recent Visitors
-Visitantes recentes
-Referrers
-
-All Referrers
-
 anchor first defined here: %s
 
 Click to search for references to this permanent anchor
@@ -462,9 +499,9 @@ Renamed from %s
 
 Renamed %1 to %2.
 
-Delete page
+Immediately delete %s
 
-Rename this page to:
+Rename %s to:
 
 Cannot highlight the language %s.
 
@@ -480,8 +517,28 @@ Next
 Próximo
 Calendar %s
 Calendário para %s
+Comments on 
+
+Comment on 
+
+Compilation for %s
+
+Compilation tag is missing a regular expression.
+
+Despamming pages
+
+Cannot find revision %s.
+
+Revert to revision %1: %2
+
+Marked as %s.
+
+Cannot find unspammed revision.
+
 Footnotes:
 
+Could not find %1.html template in %2
+
 image: %s
 imagem: %s
 Index
@@ -494,6 +551,12 @@ Define
 
 Full Link List
 
+Template without parameters
+
+The template %s is either empty or does not exist.
+
+%s returned no data.
+
 Clearing Cache
 
 Done.
@@ -514,8 +577,20 @@ Permalink to "%s"
 
 Portrait
 
+You did not answer correctly.
+
+All Referrers
+
+Referrers
+
+Updating %s
+
+Search term missing.
+
 Static Copy
 
+Back to %s
+Voltar para %s
 Alternatively, use one of the following templates:
 
 Thread: %s
@@ -540,6 +615,10 @@ Name:
 Nome:
 Failed to remove %s
 
+Contents
+
+This page is a translation of %s. 
+
 The translation is up to date.
 
 The translation is outdated.
