@@ -17,6 +17,7 @@
 #
 # This translation was last checked for Oddmuse version 1.195.
 #
+$ModulesDescription .= '<p>$Id: serbian-utf8.pl,v 1.1 2005/01/09 01:42:05 as Exp $</p>';
 %Translate = split('\n',<<END_OF_TRANSLATION);
 Reading not allowed: user, ip, or network is blocked.
 Читање није дозвољено: приступ за корисника, IP број или мрежу је блокиран.
@@ -26,6 +27,8 @@ Invalid UserName %s: not saved.
 Неисправно корисничко име %s: није снимљено.
 UserName must be 50 characters or less: not saved
 Корисничко име мора имати 50 или мање знакова: није снимљено.
+This page contains an uploaded file:
+
 XML::RSS is not available on this system.
 
 diff
@@ -36,10 +39,16 @@ history
 
 RSS parsing failed for %s
 
+No items found in %s.
+
  . . . . 
 
 Click to edit this page
 
+image
+
+download
+
 Invalid action parameter %s
 Неисправан параметар акције %s
 Invalid URL.
@@ -128,6 +137,34 @@ Rollback to %s
 Повратак на %s
 %s rolled back
 %s је враћен
+Index of all pages
+Списак свих страна:
+Wiki Version
+Приказујем верзију Викија
+Unlock Wiki
+Откључавам
+Recent Visitors
+Скори посетиоци
+Password
+Лозинка
+Run maintenance
+
+Unlock site
+
+Lock site
+
+Unlock %s
+
+Lock %s
+
+Administration
+
+Actions:
+
+Important pages:
+
+To mark a page for deletion, put <strong>%s</strong> on the first line.
+
 [Home]
 [Кућа]
 redirected from %s
@@ -154,21 +191,9 @@ by %s
 — %s
 (diff)
 (разлике)
-Run maintenance
-
-Unlock site
-
-Lock site
-
-Unlock page
-
-Lock page
-
-Comments on this page
-Коментари на овој страни
 Edit revision %s of this page
 Уреди верзију %s ове странице
-Edit text of this page
+Edit this page
 Уреди текст ове странице
 e
 
@@ -180,10 +205,10 @@ View current revision
 Прикажи тренутну верзију
 View all changes
 Прикажи све измене
-Back to %s
-
 new comment
 нови коментар
+Homepage URL:
+
 s
 
 Save
@@ -192,6 +217,8 @@ Preview
 Преглед
 Search:
 Пронађи:
+f
+
 Replace:
 Замени:
 Validate HTML
@@ -212,6 +239,8 @@ minor
 ситна
 No diff available.
 Разлика није доступна.
+Old revision:
+
 Changed:
 Измењено:
 Removed:
@@ -226,16 +255,16 @@ showing current revision instead
 уместо тога, користи се тренутна верзија
 Showing revision %s
 Приказана верзија %s
-Cannot save an nameless page.
+Cannot save a nameless page.
 Не могу да снимим безимену страну.
+Cannot save a page without revision.
+
 Cannot open %s
 
 Cannot write %s
 
 Could not get %s lock
 Нисам могао да добавим браву %s
-Unlocking
-Откључавам
 This operation may take several seconds...
 Ова операција може потрајати неколико секунди...
 Forced unlock of %s lock.
@@ -290,8 +319,6 @@ File to upload:
 Датотека коју треба окачити: 
 Files of type %s are not allowed.
 Датотеке типа %s нису дозвољене.
-Password
-Лозинка
 Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
 Ваша лозинка је снимљена у колачићу, ако су укључени. Колачићи могу бити изгубљени ако се повежете са друге машине, са другог налога, или користећи други програм.
 You are currently an administrator on this site.
@@ -312,13 +339,17 @@ This operation is restricted to administrators only...
 Ово сме да ради само администратор...
 Rule "%1" matched "%2" on this page.
 
-Index of all pages
-Списак свих страна:
-all pages
+Without normal pages
 
-permanent anchors
+Include normal pages
 
-near links
+Without permanent anchors
+
+Include permanent anchors
+
+Without near pages
+
+Include near pages
 
 (for %s)
 
@@ -346,6 +377,8 @@ Complete Content
 Потпуни садржај
 The main page is %s.
 Главна страна је %s.
+Comments on this page
+Коментари на овој страни
 Editing not allowed for %s.
 Уређивање није дозвољено за %s.
 SampleUndefinedPage
@@ -376,6 +409,12 @@ Please check whether you overwrote those changes.
 Проверите да нисте пребрисали ове те измене.
 Anonymous
 Анонимони
+Cannot delete the index file %s.
+
+Please check the directory permissions.
+
+Your changes were not saved.
+
 Could not get a lock to merge!
 Нисам могао да добавим браву за стапање!
 you
@@ -384,8 +423,8 @@ ancestor
 предак
 other
 други
-Maintenance on all pages
-Одржавање на свим странама
+Run Maintenance
+
 Maintenance not done.
 Одржавање није урађено.
 (Maintenance can only be done once every 12 hours.)
@@ -423,23 +462,21 @@ Lock for %s created.
 Lock for %s removed.
 Брава за %s је уклоњена.
 Displaying Wiki Version
-Приказујем верзију Викија
+
+Show dependencies
+
 Inter links:
 
 Near links:
 
+Show parsed link data
+
 Too many connections by %s
 Превише веза од %s
 Please do not fetch more than %1 pages in %2 seconds.
 
 Check whether the web server can create the directory %s and whether it can create files in it.
 
-Recent Visitors
-Скори посетиоци
-Referrers
-Референце
-All Referrers
-Све референце
 anchor first defined here: %s
 сидро је прво дефинисано овде: %s
 Click to search for references to this permanent anchor
@@ -462,9 +499,9 @@ Renamed from %s
 
 Renamed %1 to %2.
 
-Delete page
+Immediately delete %s
 
-Rename this page to:
+Rename %s to:
 
 Cannot highlight the language %s.
 
@@ -480,8 +517,28 @@ Next
 
 Calendar %s
 
+Comments on 
+
+Comment on 
+
+Compilation for %s
+
+Compilation tag is missing a regular expression.
+
+Despamming pages
+
+Cannot find revision %s.
+
+Revert to revision %1: %2
+
+Marked as %s.
+
+Cannot find unspammed revision.
+
 Footnotes:
 
+Could not find %1.html template in %2
+
 image: %s
 
 Index
@@ -494,6 +551,12 @@ Define
 
 Full Link List
 Потпуни списак веза
+Template without parameters
+
+The template %s is either empty or does not exist.
+
+%s returned no data.
+
 Clearing Cache
 
 Done.
@@ -514,8 +577,20 @@ Permalink to "%s"
 
 Portrait
 
+You did not answer correctly.
+
+All Referrers
+Све референце
+Referrers
+Референце
+Updating %s
+
+Search term missing.
+
 Static Copy
 
+Back to %s
+
 Alternatively, use one of the following templates:
 
 Thread: %s
@@ -540,6 +615,10 @@ Name:
 
 Failed to remove %s
 
+Contents
+
+This page is a translation of %s. 
+
 The translation is up to date.
 
 The translation is outdated.
