@@ -1,5 +1,5 @@
 # Copyright (C) 2004  Tilmann Holst
-# Copyright (C) 2004  Alex Schroeder <alex@emacswiki.org>
+# Copyright (C) 2004, 2005  Alex Schroeder <alex@emacswiki.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #    59 Temple Place, Suite 330
 #    Boston, MA 02111-1307 USA
 
-$ModulesDescription .= '<p>$Id: sidebar.pl,v 1.8 2004/10/13 20:03:04 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: sidebar.pl,v 1.12 2005/01/06 23:57:32 as Exp $</p>';
 
 use vars qw($SidebarName);
 
@@ -25,6 +25,14 @@ use vars qw($SidebarName);
 
 $SidebarName = 'SideBar';
 
+# do this later so that the user can customize $SidebarName
+push(@MyInitVariables, \&SidebarInit);
+
+sub SidebarInit {
+  $SidebarName = FreeToNormal($SidebarName); # spaces to underscores
+  push(@AdminPages, $SidebarName) unless grep(/$SidebarName/, @AdminPages); # mod_perl!
+}
+
 *OldSideBarGetHeader = *GetHeader;
 *GetHeader = *NewSideBarGetHeader;
 
