@@ -16,16 +16,17 @@
 #    59 Temple Place, Suite 330
 #    Boston, MA 02111-1307 USA
 
-$ModulesDescription .= '<p>$Id: static-copy.pl,v 1.9 2004/10/13 19:01:35 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: static-copy.pl,v 1.15 2004/12/29 00:52:27 as Exp $</p>';
 
 $Action{static} = \&DoStatic;
 
-use vars qw($StaticDir $StaticMimeTypes);
+use vars qw($StaticDir $StaticAlways %StaticMimeTypes $StaticUrl);
 
 $StaticDir = '/tmp/static';
-$StaticMimeTypes = '/etc/mime.types';
+$StaticUrl = ''; # change this!
+$StaticFilesAlways = 0; # 1 = uploaded files only, 2 = all pages
 
-my %StaticMimeTypes;
+my $StaticMimeTypes = '/etc/mime.types';
 my %StaticFiles;
 
 sub DoStatic {
@@ -47,7 +48,8 @@ sub DoStatic {
 sub StaticMimeTypes {
   my %hash;
   # the default mapping matches the default @UploadTypes...
-  open(F,$StaticMimeTypes) or return ('image/jpeg' => 'jpg', 'image/png' => 'png', );
+  open(F,$StaticMimeTypes)
+    or return ('image/jpeg' => 'jpg', 'image/png' => 'png', );
   while (<F>) {
     s/\#.*//; # remove comments
     my($type, $ext) = split;
@@ -107,7 +109,7 @@ sub StaticFileName {
   print "cannot read " . GetPageFile(StaticUrlDecode($id)) . $q->br() unless $status;
   my %hash = ParseData($data);
   my $ext = '.html';
-  if ($hash{text} =~ /#FILE ([^ \n]+)\n(.*)/s) {
+  if ($hash{text} =~ /^\#FILE ([^ \n]+)\n(.*)/s) {
     $ext = $StaticMimeTypes{$1};
     $ext = '.' . $ext if $ext;
   }
@@ -124,12 +126,15 @@ sub StaticUrlDecode {
 sub StaticWriteFile {
   my $id = shift;
   my $raw = GetParam('raw', 0);
+  my $html = GetParam('html', 1);
   my $filename = StaticFileName($id);
   OpenPage($id);
+  my ($mimetype, $data) = $Page{text} =~ /^\#FILE ([^ \n]+)\n(.*)/s;
+  return unless $html or $data;
   open(F,"> $StaticDir/$filename") or ReportError(Ts('Cannot write %s', $filename));
-  if ($Page{text} =~ /#FILE ([^ \n]+)\n(.*)/s) {
-    StaticFile($id, $1, $2);
-  } else {
+  if ($data) {
+    StaticFile($id, $mimetype, $data);
+  } elsif ($html) {
     StaticHtml($id);
   }
   close(F);
@@ -194,3 +199,75 @@ EOT
   # finish
   print F '</body></html>';
 }
+
+*StaticFilesOldDoPost = *DoPost;
+*DoPost = *StaticFilesNewDoPost;
+
+sub StaticFilesNewDoPost {
+  StaticFilesOldDoPost(@_);
+  if ($StaticAlways) {
+    # always delete
+    StaticDeleteFile($OpenPageName);
+    if ($Page{text} =~ /^\#FILE / # if a file was uploaded
+	or $StaticAlways > 1) {
+      CreateDir($StaticDir);
+      StaticWriteFile($OpenPageName);
+    }
+  }
+}
+
+*StaticOldDeletePage = *DeletePage;
+*DeletePage = *StaticNewDeletePage;
+
+sub StaticNewDeletePage {
+  my $id = shift;
+  StaticDeleteFile($id) if ($StaticAlways);
+  return StaticOldDeletePage($id);
+}
+
+sub StaticDeleteFile {
+  my $id = shift;
+  %StaticMimeTypes = StaticMimeTypes() unless %StaticMimeTypes;
+  # we don't care if the files or $StaticDir don't exist -- just delete!
+  for my $f (map { "$StaticDir/$id.$_" } (values %StaticMimeTypes, 'html')) {
+    unlink $f; # delete copies with different extensions
+  }
+}
+
+# override the default!
+sub GetDownloadLink {
+  my ($name, $image, $revision, $alt) = @_;
+  $alt = $name unless $alt;
+  my $id = FreeToNormal($name);
+  AllPagesList();
+  # if the page does not exist
+  return '[' . ($image ? T('image') : T('download')) . ':' . $name
+    . ']' . GetEditLink($id, '?', 1) unless $IndexHash{$id};
+  my $action;
+  if ($revision) {
+    $action = "action=download;id=" . UrlEncode($id) . ";revision=$revision";
+  } elsif ($UsePathInfo) {
+    $action = "download/" . UrlEncode($id);
+  } else {
+    $action = "action=download;id=" . UrlEncode($id);
+  }
+  if ($image) {
+    if ($UsePathInfo and not $revision) {
+      if ($StaticAlways and $StaticUrl) {
+	my $url = $StaticUrl;
+	my $img = UrlEncode(StaticFileName($id));
+	$url =~ s/\%s/$img/g or $url .= $img;
+	$action = $url;
+      } else {
+	$action = $ScriptName . '/' . $action;
+      }
+    } else {
+      $action = $ScriptName . '?' . $action;
+    }
+    my $result = $q->img({-src=>$action, -alt=>$alt, -class=>'upload'});
+    $result = ScriptLink(UrlEncode($id), $result, 'image') unless $id eq $OpenPageName;
+    return $result;
+  } else {
+    return ScriptLink($action, $alt, 'upload');
+  }
+}
