@@ -16,13 +16,16 @@
 #    59 Temple Place, Suite 330
 #    Boston, MA 02111-1307 USA
 
-$ModulesDescription .= '<p>$Id: toc.pl,v 1.14 2004/11/01 03:22:46 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: toc.pl,v 1.21 2004/12/05 04:03:32 as Exp $</p>';
 
 push(@MyRules, \&TocRule);
 
-# This must come *before* the usemod.pl rules.
+# This must come *before* the usemod.pl rules and adds support for
+# portrait-support.pl
 $RuleOrder{ \&TocRule } = 90;
 
+my $TocCounter = 0;
+
 sub TocRule {
 
     # copied from usemod.pl
@@ -32,7 +35,12 @@ sub TocRule {
         && m/\G(\s*\n)*(\=+)[ \t]*(?=[^=\n]+=)/cg) {
         my $depth = length($2);
         $depth = 6 if $depth > 6;
-        return CloseHtmlEnvironments() . AddHtmlEnvironment('h' . $depth);
+	my $html = CloseHtmlEnvironments() . ($PortraitSupportColorDiv ? '</div>' : '')
+	  . AddHtmlEnvironment('h' . $depth) . $q->a({-id=>'toc' . $TocCounter++})
+          . AddHtmlEnvironment('p');
+	$PortraitSupportColorDiv = 0; # after the HTML has been determined.
+	$PortraitSupportColor = 0;
+        return $html;
     } elsif (   $UseModMarkupInTitles
 	     && m/\G[ \t]*=+\n?/cg
 	     && (   InElement('h1')
@@ -41,23 +49,22 @@ sub TocRule {
 		 || InElement('h4')
 		 || InElement('h5')
 		 || InElement('h6'))) {
-        return CloseHtmlEnvironments();
+        return CloseHtmlEnvironments() . AddHtmlEnvironment('p');
     } elsif ($bol
         && !$UseModMarkupInTitles
         && m/\G(\s*\n)*(\=+)[ \t]*(.+?)[ \t]*(=+)[ \t]*\n?/cg) {
-        return CloseHtmlEnvironments() . TocWikiHeading($2, $3);
+        my $depth = length($2);
+        $depth = 6 if $depth > 6;
+	my $text = $3;
+	my $html = CloseHtmlEnvironments() . ($PortraitSupportColorDiv ? '</div>' : '') . "<h$depth>"
+	  . $q->a({-id=>'toc' . $TocCounter++}, $text) . "</h$depth>" . AddHtmlEnvironment('p');
+	$PortraitSupportColorDiv = 0; # after the HTML has been determined.
+	$PortraitSupportColor = 0;
+        return $html;
     }
     return undef;
 }
 
-sub TocWikiHeading {
-    my ($depth, $text) = @_;
-    $depth = length($depth);
-    $depth = 6 if ($depth > 6);
-    my $link = UrlEncode($text);
-    return "<h$depth><a name=\"$link\">$text</a></h$depth>";
-}
-
 *OldTocGetHeader = *GetHeader;
 *GetHeader       = *NewTocGetHeader;
 
@@ -89,7 +96,7 @@ sub TocHeadings {
         my $depth = length($1);
         my $text  = $2;
         next unless $text;
-        my $link = UrlEncode($text);
+        my $link = "toc$count";
         $text = QuoteHtml($text);
         if (not defined $HeadingsLevelStart) {
 
