@@ -1,4 +1,4 @@
-# Copyright (C) 2004  Alex Schroeder <alex@emacswiki.org>
+# Copyright (C) 2004, 2005  Alex Schroeder <alex@emacswiki.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 #    59 Temple Place, Suite 330
 #    Boston, MA 02111-1307 USA
 
-$ModulesDescription .= '<p>$Id: usemod.pl,v 1.11 2004/10/16 23:51:41 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: usemod.pl,v 1.20 2005/01/06 11:35:04 as Exp $</p>';
 
 $DefaultStyleSheet .= <<'EOT' unless $DefaultStyleSheet =~ /table\.user/; # mod_perl?
 table.user { border-style:solid; border-width:thin; }
@@ -40,17 +40,16 @@ $HtmlTags    = 0;   # 1 = allow some 'unsafe' HTML tags
 $UseModSpaceRequired = 1;  # 1 = require space after * # : ; for lists.
 $UseModMarkupInTitles = 0; # 1 = may use links and other markup in ==titles==
 
-*OldUsemodInitVariables = *InitVariables;
-*InitVariables = *NewUsemodInitVariables;
+# do this later so that the user can customize some vars
+push(@MyInitVariables, \&UsemodInit);
 
-sub NewUsemodInitVariables {
-  OldUsemodInitVariables();
-  if (not @HtmlTags) { # do not override settings in the config file
-    if ($HtmlTags) {   # allow many tags
+sub UsemodInit {
+  if (not @HtmlTags) {	 # do not override settings in the config file
+    if ($HtmlTags) {		# allow many tags
       @HtmlTags = qw(b i u font big small sub sup h1 h2 h3 h4 h5 h6 cite code
 		     em s strike strong tt var div center blockquote ol ul dl
 		     table caption br p hr li dt dd tr td th);
-    } else {	       # only allow a very small subset
+    } else {			# only allow a very small subset
       @HtmlTags = qw(b i u em strong tt);
     }
   }
@@ -62,7 +61,7 @@ sub UsemodRule {
   my $htmlre = join('|',(@HtmlTags)) unless $htmlre;
   # <pre> for monospaced, preformatted and escaped
   if ($bol && m/\G&lt;pre&gt;\n?(.*?\n)&lt;\/pre&gt;[ \t]*\n?/cgs) {
-    return CloseHtmlEnvironments() . $q->pre({-class=>'real'}, $1);
+    return CloseHtmlEnvironments() . $q->pre({-class=>'real'}, $1) . AddHtmlEnvironment('p');
   }
   # <code> for monospaced and escaped
   elsif (m/\G\&lt;code\&gt;(.*?)\&lt;\/code\&gt;/cgis) { return $q->code($1); }
@@ -78,8 +77,8 @@ sub UsemodRule {
     return OpenHtmlEnvironment('pre',1) . $str; # always level 1
   }
   # unumbered lists using *
-  elsif ($bol && m/\G(\s*\n)*(\*+)[ \t]{$UseModSpaceRequired,}/cg
-	 or InElement('li') && m/\G(\s*\n)+(\*+)[ \t]{$UseModSpaceRequired,}/cg) {
+  elsif ($bol && m/\G(\s*\n)*(\*+)[ \t]{$UseModSpaceRequired,}/cog
+	 or InElement('li') && m/\G(\s*\n)+(\*+)[ \t]{$UseModSpaceRequired,}/cog) {
     return CloseHtmlEnvironmentUntil('li') . OpenHtmlEnvironment('ul',length($2))
       . AddHtmlEnvironment('li');
   }
@@ -107,18 +106,30 @@ sub UsemodRule {
   elsif ($bol && $UseModMarkupInTitles && m/\G(\s*\n)*(\=+)[ \t]*(?=[^=\n]+=)/cg) {
     my $depth = length($2);
     $depth = 6 if $depth > 6;
-    return CloseHtmlEnvironments() . AddHtmlEnvironment('h' . $depth);
+    my $html = CloseHtmlEnvironments() . ($PortraitSupportColorDiv ? '</div>' : '')
+      . AddHtmlEnvironment('h' . $depth);
+    $PortraitSupportColorDiv = 0; # after the HTML has been determined.
+    $PortraitSupportColor = 0;
+    return $html;
   } elsif ($UseModMarkupInTitles
 	   && m/\G[ \t]*=+\n?/cg
 	   && (InElement('h1') || InElement('h2') || InElement('h3')
 		|| InElement('h4') || InElement('h5') || InElement('h6'))) {
-    return CloseHtmlEnvironments();
+    return CloseHtmlEnvironments() . AddHtmlEnvironment('p');
   } elsif ($bol && !$UseModMarkupInTitles && m/\G(\s*\n)*(\=+)[ \t]*(.+?)[ \t]*(=+)[ \t]*\n?/cg) {
-    return CloseHtmlEnvironments() . WikiHeading($2, $3);
+    my $html = CloseHtmlEnvironments() . ($PortraitSupportColorDiv ? '</div>' : '')
+      . WikiHeading($2, $3) . AddHtmlEnvironment('p');
+    $PortraitSupportColorDiv = 0; # after the HTML has been determined.
+    $PortraitSupportColor = 0;
+    return $html;
   }
   # horizontal lines using ----
   elsif ($bol && m/\G(\s*\n)*----+[ \t]*\n?/cg) {
-    return CloseHtmlEnvironments() . $q->hr();
+    my $html = CloseHtmlEnvironments() . ($PortraitSupportColorDiv ? '</div>' : '')
+      . $q->hr() . AddHtmlEnvironment('p');
+    $PortraitSupportColorDiv = 0;
+    $PortraitSupportColor = 0;
+    return $html;
   }
   # tables using || -- the first row of a table
   elsif ($bol && m/\G(\s*\n)*((\|\|)+)([ \t])*(?=.*\|\|[ \t]*(\n|$))/cg) {
@@ -139,7 +150,7 @@ sub UsemodRule {
   }
   # tables using || -- since "next row" was taken care of above, this must be the last row
   elsif (InElement('td') && m/\G[ \t]*((\|\|)+)[ \t]*/cg) {
-    return CloseHtmlEnvironments();
+    return CloseHtmlEnvironments() . AddHtmlEnvironment('p');
   }
   # RFC
   elsif (m/\G$RFCPattern/cog) { return &RFC($1); }
